
jare_run:
I have added "jare_run" which simply takes 3 values 

1. Input value (input(input value))
2. Questions list (questions = ["Hello", "How are you"])
3. Answers List (answers = ["Hi", "I am good thanks!"])

Then it combines them in to a dictionary and then asks the user for an input and if that input is in the dictionary then it prints the response(from the Answers list)